from setuptools import Extension, setup

ext = Extension(
    name='soundbox',
    sources=['soundbox.cpp'],
)

setup(
    name='soundbox',
    version='0.3.0',
    ext_modules=[ext],
    packages=['soundbox_core'],
    package_data={
        'soundbox_core': ['soft_oal.dll'],
        'soundbox-stubs': ['__init__.pyi'],
    },
    include_package_data=True,
)



import os


def load(data, core):
    if isinstance(data, tuple):
        return data

    if isinstance(data, str):
        with open(data, 'rb') as f:
            data = f.read()

    decoder = {
        b'qoaf': core.qoa_decode,
        b'OggS': core.ogg_decode,
    }[data[:4]]

    return decoder(data)


def find_openal():
    return os.path.abspath(os.path.normpath(os.path.join(os.path.dirname(__file__), 'soft_oal.dll')))
